@@ -34,6 +34,20 @@
  (scheme-mode
   .
   ((geiser-active-implementations . (guile))
+
+   ;; Guix package
+   (eval . (put 'package 'scheme-indent-function 0))
+   (eval . (put 'origin 'scheme-indent-function 0))
+
+   ;; Guix 'modify-phases' and its keywords.
+   (eval . (put 'modify-phases 'scheme-indent-function 1))
+   (eval . (put 'replace 'scheme-indent-function 1))
+   (eval . (put 'add-before 'scheme-indent-function 2))
+   (eval . (put 'add-after 'scheme-indent-function 2))
+
+   ;; Guix utils
+   (eval . (put 'substitute* 'scheme-indent-function 1))
+
    (eval
     .
     (progn
