@@ -1,7 +1,7 @@
 #! /bin/sh
 
 # GNU Mes --- Maxwell Equations of Software
-# Copyright © 2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+# Copyright © 2019, 2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 #
 # This file is part of GNU Mes.
 #
@@ -36,8 +36,10 @@ lib/mes/oputs.c
 
 if test $mes_libc = mes; then
     libc_mini_shared_SOURCES="$libc_mini_shared_SOURCES
-lib/$mes_kernel/$mes_cpu-mes-$compiler/mini.c
+lib/mes/globals.c
 lib/stdlib/exit.c
+lib/$mes_kernel/$mes_cpu-mes-$compiler/_exit.c
+lib/$mes_kernel/$mes_cpu-mes-$compiler/_write.c
 lib/stdlib/puts.c
 lib/string/strlen.c
 "
@@ -76,11 +78,21 @@ lib/mes/mini-write.c
 "
 fi
 
+libmescc_SOURCES="
+lib/mes/globals.c
+lib/linux/$mes_cpu-mes-$compiler/syscall-internal.c
+"
+
+if test $mes_cpu = arm; then
+    libmescc_SOURCES="$libmescc_SOURCES
+lib/mes/div.c
+"
+fi
+
 libmes_SOURCES="
 $libc_mini_shared_SOURCES
 lib/ctype/isnumber.c
 lib/mes/abtol.c
-lib/mes/div.c
 lib/mes/eputc.c
 lib/mes/fdgetc.c
 lib/mes/fdputc.c
@@ -153,6 +165,7 @@ lib/string/memset.c
 lib/string/strcmp.c
 lib/string/strcpy.c
 lib/string/strncmp.c
+lib/posix/raise.c
 "
 
 if test $mes_kernel = gnu; then
@@ -201,6 +214,8 @@ lib/linux/time.c
 lib/linux/unlink.c
 lib/linux/waitpid.c
 lib/linux/$mes_cpu-mes-$compiler/syscall.c
+lib/linux/getpid.c
+lib/linux/kill.c
 "
 fi
 
@@ -208,6 +223,15 @@ libtcc1_SOURCES="
 lib/libtcc1.c
 "
 
+if test $mes_cpu = arm; then
+    libtcc1_SOURCES="$libtcc1_SOURCES
+lib/mes/div.c
+lib/string/__memcpy.c
+lib/string/__memmove.c
+lib/string/__memset.c
+"
+fi
+
 libc_tcc_SOURCES="
 $libc_SOURCES
 lib/ctype/islower.c
@@ -300,7 +324,6 @@ lib/posix/alarm.c
 lib/posix/execl.c
 lib/posix/execlp.c
 lib/posix/mktemp.c
-lib/posix/raise.c
 lib/posix/sbrk.c
 lib/posix/sleep.c
 lib/posix/unsetenv.c
@@ -385,11 +408,9 @@ lib/linux/getdents.c
 lib/linux/getegid.c
 lib/linux/geteuid.c
 lib/linux/getgid.c
-lib/linux/getpid.c
 lib/linux/getppid.c
 lib/linux/getrusage.c
 lib/linux/getuid.c
-lib/linux/kill.c
 lib/linux/link.c
 lib/linux/lstat.c
 lib/linux/mkdir.c
