@@ -1,5 +1,5 @@
 ;;; GNU Mes --- Maxwell Equations of Software
-;;; Copyright © 2016,2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2016,2017,2018,2019,2020,2021 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 ;;;
 ;;; This file is part of GNU Mes.
 ;;;
@@ -46,32 +46,40 @@
   #:use-module (guix download)
   #:use-module (guix git-download)
   #:use-module (guix licenses)
-  #:use-module (guix packages))
+  #:use-module (guix packages)
+  #:use-module (guix utils))
 
 (define %source-dir (getcwd))
 
 (define-public mescc-tools
   (package
     (name "mescc-tools")
-    (version "0.6.1")
-    (source (origin
-              (method url-fetch)
-              (uri (string-append
-                    "http://git.savannah.nongnu.org/cgit/mescc-tools.git/snapshot/"
-                    name "-Release_" version
-                    ".tar.gz"))
-              (file-name (string-append name "-" version ".tar.gz"))
-              (sha256
-               (base32
-                "06jpvq6xfjzn2al6b4rdwd3zv3h4cvilc4n9gqcnjr9cr6wjpw2n"))))
+    (version "0.7.0")
+    (source
+     (origin
+       (method url-fetch)
+       (uri (string-append
+             "http://git.savannah.nongnu.org/cgit/mescc-tools.git/snapshot/"
+             name "-Release_" version
+             ".tar.gz"))
+       (file-name (string-append name "-" version ".tar.gz"))
+       (sha256
+        (base32
+         "1p1ijia4rm3002f5sypidl9v5gq0mlch9b0n61rpxkdsaaxjqax3"))))
     (build-system gnu-build-system)
-    (supported-systems '("i686-linux" "x86_64-linux"))
+    (supported-systems
+     '("aarch64-linux" "armhf-linux" "i686-linux" "x86_64-linux"))
     (arguments
      `(#:make-flags (list (string-append "PREFIX=" (assoc-ref %outputs "out"))
-                          "CC=gcc")
+                          (string-append "CC=" ,(cc-for-target)))
        #:test-target "test"
        #:phases (modify-phases %standard-phases
-                  (delete 'configure))))
+                  (delete 'configure)
+                  (add-after 'unpack 'patch-prefix
+                    (lambda _
+                      (substitute* "sha256.sh"
+                        (("/usr/bin/sha256sum") (which "sha256sum")))
+                      #t)))))
     (synopsis "Tools for the full source bootstrapping process")
     (description
      "Mescc-tools is a collection of tools for use in a full source
@@ -81,7 +89,7 @@ get_machine.")
     (home-page "https://savannah.nongnu.org/projects/mescc-tools")
     (license gpl3+)))
 
-(define-public nyacc
+(define-public nyacc-0.99
   (package
     (name "nyacc")
     (version "0.99.0")
@@ -120,50 +128,86 @@ extensive examples, including parsers for the Javascript and C99 languages.")
     (home-page "https://savannah.nongnu.org/projects/nyacc")
     (license (list gpl3+ lgpl3+))))
 
+(define-public nyacc
+  (package
+    (inherit nyacc-0.99)
+    (version "1.00.2")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://savannah/nyacc/nyacc-"
+                                  version ".tar.gz"))
+              (modules '((guix build utils)))
+              (snippet
+               '(begin
+                  (substitute* (find-files "." "^Makefile\\.in$")
+                    (("^SITE_SCM_DIR =.*")
+                     "SITE_SCM_DIR = \
+@prefix@/share/guile/site/@GUILE_EFFECTIVE_VERSION@\n")
+                    (("^SITE_SCM_GO_DIR =.*")
+                     "SITE_SCM_GO_DIR = \
+@prefix@/lib/guile/@GUILE_EFFECTIVE_VERSION@/site-ccache\n")
+                    (("^INFODIR =.*")
+                     "INFODIR = @prefix@/share/info\n")
+                    (("^DOCDIR =.*")
+                     "DOCDIR = @prefix@/share/doc/$(PACKAGE_TARNAME)\n"))
+                  #t))
+              (sha256
+               (base32
+                "065ksalfllbdrzl12dz9d9dcxrv97wqxblslngsc6kajvnvlyvpk"))))
+    (inputs
+     `(("guile" ,guile-3.0)))))
+
 (define-public mes
-  (let ((triplet "i686-unknown-linux-gnu")
-        (version "0.22"))
-    (package
-      (name "mes")
-      (version version)
-      (source (origin
-                (method url-fetch)
-                (uri (string-append
-                      "https://ftp.gnu.org/pub/gnu/mes/mes-" version ".tar.gz"))
-                (sha256
-                 (base32 #!mes!# "04pajp8v31na34ls4730ig5f6miiplhdvkmsb9ls1b8bbmw2vb4n"))))
-      (build-system gnu-build-system)
-      (supported-systems '("i686-linux" "x86_64-linux"))
-      (propagated-inputs
-       `(("mescc-tools" ,mescc-tools)
-         ("nyacc" ,nyacc)))
-      (native-inputs
-       `(("guile" ,guile-2.2)
-         ,@(if (string-prefix? "x86_64-linux" (or (%current-target-system)
-                                                  (%current-system)))
-               ;; Use cross-compiler rather than #:system "i686-linux" to get
-               ;; MesCC 64 bit .go files installed ready for use with Guile.
-               `(("i686-linux-binutils" ,(cross-binutils triplet))
-                 ("i686-linux-gcc" ,(cross-gcc triplet)))
-               '())
-         ("graphviz" ,graphviz)
-         ("help2man" ,help2man)
-         ("perl" ,perl)                ; build-aux/gitlog-to-changelog
-         ("texinfo" ,texinfo)))
-      (arguments
-       `(#:strip-binaries? #f)) ; binutil's strip b0rkes MesCC/M1/hex2 binaries
-      (synopsis "Scheme interpreter and C compiler for full source bootstrapping")
-      (description
-       "GNU Mes--Maxwell Equations of Software--brings the Reduced Binary Seed
+  (package
+    (name "mes")
+    (version #!mes!# "0.22")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append
+                    "https://ftp.gnu.org/pub/gnu/mes/mes-" version ".tar.gz"))
+              (sha256
+               (base32 #!mes!# "16ngnrdlzik19sdzy9d7krg57q6ws3xrckwkk2gs7q4h5f3x1z99"))))
+    (build-system gnu-build-system)
+    (supported-systems '("aarch64-linux" "armhf-linux" "i686-linux" "x86_64-linux"))
+    (propagated-inputs
+     `(("mescc-tools" ,mescc-tools)
+       ("nyacc" ,nyacc)))
+    (native-inputs
+     `(("guile" ,guile-3.0-latest)
+       ,@(cond ((string-prefix? "x86_64-linux" (or (%current-target-system)
+                                                   (%current-system)))
+                ;; Use cross-compiler rather than #:system "i686-linux" to get
+                ;; MesCC 64 bit .go files installed ready for use with Guile.
+                (let ((triplet "i686-unknown-linux-gnu"))
+                  `(("i686-linux-binutils" ,(cross-binutils triplet))
+                    ("i686-linux-gcc" ,(cross-gcc triplet)))))
+               ((string-prefix? "aarch64-linux" (or (%current-target-system)
+                                                    (%current-system)))
+                ;; Use cross-compiler rather than #:system "armhf-linux" to get
+                ;; MesCC 64 bit .go files installed ready for use with Guile.
+                (let ((triplet "arm-linux-gnueabihf"))
+                  `(("arm-linux-binutils" ,(cross-binutils triplet))
+                    ("arm-linux-gcc" ,(cross-gcc triplet)))))
+               (else
+                '()))
+       ("graphviz" ,graphviz)
+       ("help2man" ,help2man)
+       ("perl" ,perl)                   ; build-aux/gitlog-to-changelog
+       ("texinfo" ,texinfo)))
+    (arguments
+     `(#:strip-binaries? #f)) ; binutil's strip b0rkes MesCC/M1/hex2 binaries
+    (synopsis "Scheme interpreter and C compiler for full source bootstrapping")
+    (description
+     "GNU Mes--Maxwell Equations of Software--brings the Reduced Binary Seed
 bootstrap to Guix and aims to help create full source bootstrapping for
 GNU/Linux distributions.  It consists of a mutual self-hosting Scheme
 interpreter in C and a Nyacc-based C compiler in Scheme and is compatible with
 Guile.")
-      (home-page "https://www.gnu.org/software/mes")
-      (license gpl3+))))
+    (home-page "https://www.gnu.org/software/mes")
+    (license gpl3+)))
 
 (define-public mes.git
- (let ((version "0.22")
+ (let ((version #!mes!# "0.22")
         (revision "0")
         (commit (read-string (open-pipe "git show HEAD | head -1 | cut -d ' ' -f 2" OPEN_READ))))
     (package
