@@ -20,17 +20,17 @@
 #ifndef __MES_MEMORY_H
 #define __MES_MEMORY_H 1
 
-#if WITH_GLIBC
+#if SYSTEM_LIBC
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
 #undef __MES_MEMORY_H
 #include_next <memory.h>
 
-#else // ! WITH_GLIBC
+#else // ! SYSTEM_LIBC
 
 #include <string.h>
 
-#endif // ! WITH_GLIBC
+#endif // ! SYSTEM_LIBC
 
 #endif // __MES_MEMORY_H
