@@ -18,11 +18,11 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
 
 int
 fdputc (int c, int fd)
 {
-  write (fd, (char*)&c, 1);
+  write (fd, (char *) &c, 1);
   return 0;
 }
