@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2016,2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2016,2017,2018,2019,2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -20,21 +20,27 @@
 
 #include <assert.h>
 #include <mes/lib.h>
+#include <stdint.h>
+
+#define STR(x) #x
+#define XSTR(s) STR(s)
 
 char *
-ntoab (long x, int base, int signed_p)
+ntoab (long x, unsigned base, int signed_p)
 {
   static char itoa_buf[20];
   char *p = itoa_buf + 11;
   *p-- = 0;
-  assert(base > 0);
+  assert(base > 1);
 
   int sign_p = 0;
   unsigned long u;
   if (signed_p && x < 0)
     {
       sign_p = 1;
-      u = -x;
+      /* Avoid LONG_MIN */
+      u = (unsigned long) (-(x + 1));
+      ++u;
     }
   else
     u = x;
