@@ -21,7 +21,7 @@
 #include <stdio.h>
 
 int
-fputc (int c, FILE* stream)
+fputc (int c, FILE * stream)
 {
-  return fdputc (c, (int)stream);
+  return fdputc (c, (long) stream);
 }
