@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -18,17 +18,22 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
 #include <stdio.h>
+#include <unistd.h>
 
 int
-fseek (FILE *stream, long offset, int whence)
+fseek (FILE * stream, long offset, int whence)
 {
-  int pos = lseek ((int)stream, offset, whence);
+  int filedes = (long) stream;
+  off_t pos = lseek (filedes, offset, whence);
   if (__mes_debug ())
     {
-      eputs ("fread fd="); eputs (itoa ((int)stream));
-      eputs ("  =>"); eputs (itoa (pos)); eputs ("\n");
+      eputs ("fread fd=");
+      eputs (itoa (filedes));
+      eputs ("  =>");
+      eputs (itoa (pos));
+      eputs ("\n");
     }
   if (pos >= 0)
     return 0;
