@@ -18,11 +18,11 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
 #include <signal.h>
 
 int
-sigaddset (sigset_t *set, int signum)
+sigaddset (sigset_t * set, int signum)
 {
   return 0;
 }
