@@ -18,11 +18,11 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
 #include <signal.h>
 
 int
-sigemptyset (sigset_t *set)
+sigemptyset (sigset_t * set)
 {
   return 0;
 }
