@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -19,17 +19,20 @@
  */
 
 #include <setjmp.h>
+#include <stdlib.h>
 
 void
 longjmp (jmp_buf env, int val)
 {
   val = val == 0 ? 1 : val;
+  // *INDENT-OFF*
   asm (
        "mov    0x00(%rdi),%rbp\n\t"     // env->__bp
        "mov    0x08(%rdi),%rbx\n\t"     // env->__pc
        "mov    0x10(%rdi),%rsp\n\t"     // env->__sp
        "jmp    *%rbx\n\t"               // jmp *PC
        );
+  // *INDENT-ON*
   // not reached
   exit (42);
 }
@@ -38,11 +41,13 @@ int
 setjmp (jmp_buf env)
 {
   long *p;
+  // *INDENT-OFF*
   asm ("mov    %%rbp,%0"
        : "=r" (p)
        : //no inputs ""
        );
-  env[0].__bp = p;
+  // *INDENT-ON*
+  env[0].__bp = (long) p;
   env[0].__pc = p[1];
   env[0].__sp = p[0];
   return 0;
