@@ -136,6 +136,9 @@
       (if (null? (cdr rest)) (car rest)
           (append2 (car rest) (apply append (cdr rest))))))
 
+(if (not (defined? '%datadir))
+    (module-define! (current-module) '%datadir "mes"))
+
 (define %moduledir (string-append %datadir "/module/"))
 
 (include (string-append %moduledir "mes/type-0.mes"))
@@ -239,7 +242,7 @@ Scheme interpreter for bootstrapping the GNU system.
 
 Options:
   [-s] FILE            load source code from FILE, and exit
-  -c EXPR              evalute expression EXPR, and exit
+  -c EXPR              evaluate expression EXPR, and exit
   --                   stop scanning arguments; run interactively
 
 The above switches stop argument processing, and pass all
