@@ -32,6 +32,8 @@
             <cell:symbol>
             <cell:vector>
 
+            %arch
+            %compiler
             append2
             core:apply
             core:car
@@ -45,13 +47,21 @@
             core:write-error
             core:write-port
             core:type
+            %compiler
             equal2?
+            keyword->string
             pmatch-car
             pmatch-cdr
             )
   ;;#:re-export (open-input-file open-input-string with-input-from-string)
   )
 
+(cond-expand
+ (guile-2)
+ (guile
+  (define %host-type (string-append (utsname:machine (uname)) "linux-gnu")))
+ (else))
+
 (cond-expand
  (guile
   (define pmatch-car car)
@@ -82,6 +92,11 @@
   (define <cell:string> 10)
   (define <cell:symbol> 11)
   (define <cell:vector> 15)
+  (define %arch (car (string-split %host-type #\-)))
+  (define %compiler "gnuc")
+
+  (define %compiler "gnuc")
+  (define keyword->string (compose symbol->string keyword->symbol))
 
   (define (core:type x)
     (cond ((guile:keyword? x) <cell:keyword>)
