@@ -58,7 +58,7 @@
 
 (define (parse-opts args)
   (let* ((option-spec
-          '((align)
+          '((align (value #t))
             (arch (value #t))
             (assemble (single-char #\c))
             (base-address (value #t))
@@ -66,6 +66,7 @@
             (define (single-char #\D) (value #t))
             (debug-info (single-char #\g))
             (dumpmachine)
+            (print-libgcc-file-name)
             (fno-builtin)
             (fno-stack-protector)
             (help (single-char #\h))
@@ -91,8 +92,9 @@
          (help? (option-ref options 'help #f))
          (files (option-ref options '() '()))
          (dumpmachine? (option-ref options 'dumpmachine #f))
+         (print-libgcc-file-name? (option-ref options 'print-libgcc-file-name #f))
          (version? (option-ref options 'version #f))
-         (usage? (and (not dumpmachine?) (not help?) (not version?) (null? files))))
+         (usage? (and (not dumpmachine?) (not print-libgcc-file-name?) (not help?) (not version?) (null? files))))
     (cond (version? (format #t "mescc (GNU Mes) ~a\n" %version) (exit 0))
           (else
            (and (or help? usage?)
@@ -101,7 +103,7 @@ Usage: mescc [OPTION]... FILE...
 C99 compiler in Scheme for bootstrapping the GNU system.
 
 Options:
-  --align             align globals
+  --align=SYMBOL      align SYMBOL {functions,globals,none} [functions]
   --arch=ARCH         compile for ARCH [~a]
   --kernel=ARCH       compile for KERNEL [~a]
   -dumpmachine        display the compiler's target machine
@@ -110,15 +112,15 @@ Options:
   --numbered-arch     mescc-tools use numbered arch
   -D DEFINE[=VALUE]   define DEFINE [VALUE=1]
   -E                  preprocess only; do not compile, assemble or link
-  -g                  add debug info [GDB, objdump] TODO: hex2 footer
+  -g                  add debug info (call stack in GDB)
   -h, --help          display this help and exit
   -I DIR              append DIR to include path
   -L DIR              append DIR to library path
   -l LIBNAME          link with LIBNAME
   -m BITS             compile for BITS bits [32]
-  -nodefaultlibs      do not use libc.o when linking
+  -nodefaultlibs      do not use libc.o nor libmescc.a when linking
   -nostartfiles       do not use crt1.o when linking
-  -nostdlib           do not use crt1.o or libc.o when linking
+  -nostdlib           do not use crt1.o or libc.o or libmescc.a when linking
   -o FILE             write output to FILE
   -O LEVEL            use optimizing LEVEL
   -S                  preprocess and compile only; do not assemble or link
@@ -175,6 +177,7 @@ General help using GNU software: <http://gnu.org/gethelp/>
          (options (acons 'numbered-arch? numbered-arch? options))
          (dumpmachine? (option-ref options 'dumpmachine #f))
          (preprocess? (option-ref options 'preprocess #f))
+         (print-libgcc-file-name? (option-ref options 'print-libgcc-file-name #f))
          (compile? (option-ref options 'compile #f))
          (assemble? (option-ref options 'assemble #f))
          (verbose? (count-opt options 'verbose)))
@@ -183,6 +186,7 @@ General help using GNU software: <http://gnu.org/gethelp/>
       (when (> verbose? 1)
         (format (current-error-port) "options=~s\n" options)))
     (cond (dumpmachine? (display (mescc:get-host options)))
+          (print-libgcc-file-name? (display "-lmescc\n"))
           (preprocess? (mescc:preprocess options))
           (compile? (mescc:compile options))
           (assemble? (mescc:assemble options))
