@@ -1,5 +1,5 @@
 ;;; GNU Mes --- Maxwell Equations of Software
-;;; Copyright © 2016,2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2016,2017,2018,2019,2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 ;;;
 ;;; This file is part of GNU Mes.
 ;;;
@@ -23,6 +23,8 @@
   #:use-module (ice-9 getopt-long)
   #:use-module (mes misc)
 
+  #:use-module (mescc info)
+  #:use-module (mescc armv4 info)
   #:use-module (mescc i386 info)
   #:use-module (mescc x86_64 info)
   #:use-module (mescc preprocess)
@@ -58,7 +60,7 @@
          (prefix (option-ref options 'prefix ""))
          (machine (option-ref options 'machine "32"))
          (arch (arch-get options))
-         (defines (cons (arch-get-define options) defines))
+         (defines (append (arch-get-defines options) defines))
          (verbose? (count-opt options 'verbose)))
     (with-output-to-file ast-file-name
       (lambda _ (for-each (cut c->ast prefix defines includes arch pretty-print/write verbose? <>) files)))))
@@ -77,11 +79,16 @@
                              (else (replace-suffix input-base ".s"))))
          (infos (map (cut file->info options <>) files))
          (verbose? (count-opt options 'verbose))
-         (align? (option-ref options 'align #f)))
+         (numbered-arch? (option-ref options 'numbered-arch? #f))
+         (align (filter-map (multi-opt 'align) options))
+         (align (if (null? align) '(functions) (map string->symbol align)))
+         (align (if (not numbered-arch?) align
+                    ;; function alignment not supported by MesCC-Tools 0.5.2
+                    (filter (negate (cut eq? <> 'functions)) align))))
     (when verbose?
       (stderr "dumping: ~a\n" M1-file-name))
     (with-output-to-file M1-file-name
-      (cut infos->M1 M1-file-name infos #:align? align? #:verbose? verbose?))
+      (cut infos->M1 M1-file-name infos #:align align #:verbose? verbose?))
     M1-file-name))
 
 (define (file->info options file-name)
@@ -95,7 +102,7 @@
          (includes (cons (option-ref options 'includedir #f) includes))
          (includes (cons dir includes))
          (prefix (option-ref options 'prefix ""))
-         (defines (cons (arch-get-define options) defines))
+         (defines (append (arch-get-defines options) defines))
          (arch (arch-get options))
          (verbose? (count-opt options 'verbose)))
     (with-input-from-file file-name
@@ -143,8 +150,9 @@
                          (append hex2-files
                                  (list (infos->hex2 options hex2-file-name infos)))))
          (default-libraries (if (or (option-ref options 'nodefaultlibs #f)
-                                    (option-ref options 'nostdlib #f)) '()
-                                    '("c")))
+                                    (option-ref options 'nostdlib #f))
+                                '()
+                                '("mescc" "c")))
          (libraries (filter-map (multi-opt 'library) options))
          (libraries (delete-duplicates (append libraries default-libraries)))
          (hex2-libraries (map (cut find-library options ".a" <>) libraries))
@@ -165,11 +173,16 @@
          (options (acons 'compile #t options)) ; ugh
          (options (acons 'output hex2-file-name options))
          (verbose? (count-opt options 'verbose))
-         (align? (option-ref options 'align #f)))
+         (numbered-arch? (option-ref options 'numbered-arch? #f))
+         (align (filter-map (multi-opt 'align) options))
+         (align (if (null? align) '(functions) (map string->symbol align)))
+         (align (if (not numbered-arch?) align
+                    ;; function alignment not supported by MesCC-Tools 0.5.2
+                    (filter (negate (cut eq? <> 'functions)) align))))
     (when verbose?
       (stderr "dumping: ~a\n" M1-file-name))
     (with-output-to-file M1-file-name
-      (cut infos->M1 M1-file-name infos #:align? align?))
+      (cut infos->M1 M1-file-name infos #:align align))
     (or (M1->hex2 options (list M1-file-name))
         (exit 1))))
 
@@ -240,7 +253,7 @@
                       ,@(append-map (cut list "-f" <>) M1-files)
                       "-o" ,M1-blood-elf-footer)))
     (when (and verbose? (> verbose? 1))
-        (format (current-error-port) "~a\n" (string-join command)))
+      (format (current-error-port) "~a\n" (string-join command)))
     (and (zero? (apply assert-system* command))
          (let* ((options (acons 'compile #t options)) ; ugh
                 (options (acons 'output blood-elf-footer options)))
@@ -248,8 +261,8 @@
 
 (define (replace-suffix file-name suffix)
   (let* ((parts (string-split file-name #\.))
-         (base (if (pair? (cdr parts)) (drop-right parts 1)))
-         (old-suffix (last parts))
+         (base (if (pair? (cdr parts)) (drop-right parts 1) (list file-name)))
+         (old-suffix (if (pair? (cdr parts)) (last parts) ""))
          (program-prefix (cond ((string-prefix? "arm-mes-" old-suffix) ".arm-mes-")
                                ((string-prefix? "x86-mes-" old-suffix) ".x86-mes-")
                                ((string-prefix? "x86_64-mes-" old-suffix) ".x86_64-mes-")
@@ -265,11 +278,21 @@
 (define* (arch-find options file-name #:key kernel)
   (let* ((srcdest (or (getenv "srcdest") ""))
          (srcdir-lib (string-append srcdest "lib"))
+         (srcdir-mescc-lib (string-append srcdest "mescc-lib"))
+         (libdir (option-ref options 'libdir "lib"))
+         (libdir-mescc (string-append
+                        (dirname (option-ref options 'libdir "lib"))
+                        "/mescc-lib"))
          (arch (string-append (arch-get options) "-mes"))
-         (path (cons* "."
-                      srcdir-lib
-                      (option-ref options 'libdir "lib")
-                      (filter-map (multi-opt 'library-dir) options)))
+         (path (append (if (getenv "MES_UNINSTALLED")
+                           (list srcdir-mescc-lib
+                                 srcdir-lib
+                                 libdir-mescc)
+                           '())
+                       (list libdir)
+                       (or (and=> (getenv "LIBRARY_PATH")
+                                  (cut string-split <> #\:)) '())
+                       (filter-map (multi-opt 'library-dir) options)))
          (arch-file-name (string-append arch "/" file-name))
          (arch-file-name (if kernel (string-append kernel "/" arch-file-name)
                              arch-file-name))
@@ -299,7 +322,8 @@
          (arch (option-ref options 'arch #f)))
     (if machine (cond ((member arch '("x86" "x86_64")) (cond ((equal? machine "32") "x86")
                                                              ((equal? machine "64") "x86_64")))
-                      ((equal? arch "arm") (cond ((equal? machine "32") "arm"))))
+                      ((equal? arch "arm") (cond ((equal? machine "32") "arm")
+                                                 ((equal? machine "arm") "arm"))))
         arch)))
 
 (define (mescc:get-host options)
@@ -313,11 +337,25 @@
           ((equal? arch "x86") (x86-info))
           ((equal? arch "x86_64") (x86_64-info)))))
 
-(define (arch-get-define options)
-  (let ((arch (arch-get options)))
-    (cond ((equal? arch "arm") "__arm__=1")
-          ((equal? arch "x86") "__i386__=1")
-          ((equal? arch "x86_64") "__x86_64__=1"))))
+(define (arch-get-defines options)
+  (let* ((arch (arch-get options))
+         (info (arch-get-info options))
+         (types (.types info)))
+    (define (sizeof type)
+      (type:size (assoc-ref types type)))
+    (let ((int (sizeof "int"))
+          (long (sizeof "long"))
+          (long-long (sizeof "long long")))
+      (cons (cond ((equal? arch "arm")
+                   "__arm__=1")
+                  ((equal? arch "x86")
+                   "__i386__=1")
+                  ((equal? arch "x86_64")
+                   "__x86_64__=1"))
+            `(,(string-append "__SIZEOF_INT__=" (number->string int))
+              ,(string-append "__SIZEOF_LONG__=" (number->string long))
+              ,@(if (< long-long 8) '() ;C99: long long must be >= 8
+                    '("__SIZEOF_LONG_LONG__=8")))))))
 
 (define (arch-get-machine options)
   (let* ((machine (option-ref options 'machine #f))
@@ -334,7 +372,7 @@
 
 (define (arch-get-architecture options)
   (let* ((arch (arch-get options))
-        (numbered-arch? (option-ref options 'numbered-arch? #f))
+         (numbered-arch? (option-ref options 'numbered-arch? #f))
         (flag (if numbered-arch? "--Architecture" "--architecture")))
     (list flag
           (cond ((equal? arch "arm") (if numbered-arch? "40" "armv7l"))
